## 📖 Melhorias para hoje 
- [] Criar Em ByteManager uma seção para atualizaçoes constantes em respectivos dias e horarios , o usuario solicita as atualizaçoes constantes informando o repositorio os dias e horarios de trabalho


